@@ -134,7 +134,7 @@ fn merge_requests_from_worker(
             let new_count;
             // Add user count into global count
             if let Some(existing_status_code_count) =
-                merged_request.status_code_counts.get(&status_code)
+                merged_request.status_code_counts.get(status_code)
             {
                 new_count = *existing_status_code_count + *count;
             }
@@ -307,7 +307,12 @@ pub(crate) async fn manager_main(mut goose_attack: GooseAttack) -> GooseAttack {
     // Initialize the optional task metrics.
     goose_attack
         .metrics
-        .initialize_task_metrics(&goose_attack.task_sets, &goose_attack.configuration);
+        .initialize_task_metrics(
+            &goose_attack.task_sets,
+            &goose_attack.configuration,
+            &goose_attack.defaults,
+        )
+        .expect("failed to initialize task metrics");
 
     // Update metrics, which doesn't happen automatically on the Master as we don't
     // invoke start_attack. Hatch rate is required here so unwrap() is safe.
