@@ -1,4 +1,4 @@
-use httpmock::{Method::GET, MockRef, MockServer};
+use httpmock::{Method::GET, Mock, MockServer};
 use serial_test::serial;
 use std::fmt;
 
@@ -79,7 +79,7 @@ pub async fn get_error(user: &GooseUser) -> GooseTaskResult {
 }
 
 // All tests in this file run against common endpoints.
-fn setup_mock_server_endpoints(server: &MockServer) -> Vec<MockRef> {
+fn setup_mock_server_endpoints(server: &MockServer) -> Vec<Mock> {
     vec![
         // First, set up INDEX_PATH, store in vector at INDEX_KEY.
         server.mock(|when, then| {
@@ -104,7 +104,7 @@ fn get_tasks() -> GooseTaskSet {
 // Helper to confirm all variations generate appropriate results.
 fn validate_test(
     goose_metrics: GooseMetrics,
-    mock_endpoints: &[MockRef],
+    mock_endpoints: &[Mock],
     test_type: &TestType,
     log_files: &LogFiles,
 ) {
@@ -450,6 +450,20 @@ fn test_requests_logs_raw_gaggle() {
     run_gaggle_test(TestType::Requests, "raw");
 }
 
+#[test]
+// Enable pretty-formatted requests log.
+fn test_requests_logs_pretty() {
+    run_standalone_test(TestType::Requests, "pretty");
+}
+
+#[test]
+#[serial]
+#[cfg_attr(not(feature = "gaggle"), ignore)]
+// Enable pretty-formatted requests log, in Gaggle mode.
+fn test_requests_logs_pretty_gaggle() {
+    run_gaggle_test(TestType::Requests, "pretty");
+}
+
 #[test]
 // Enable json-formatted tasks log.
 fn test_tasks_logs_json() {
@@ -577,7 +591,7 @@ fn test_debug_logs_csv_gaggle() {
 }
 
 #[test]
-// Enable raw-formatted debug log and metrics log.
+// Enable raw-formatted logs.
 fn test_all_logs_raw() {
     run_standalone_test(TestType::All, "raw");
 }
@@ -585,7 +599,21 @@ fn test_all_logs_raw() {
 #[test]
 #[serial]
 #[cfg_attr(not(feature = "gaggle"), ignore)]
-// Enable raw-formatted debug log and metrics log, in Gaggle mode.
+// Enable raw-formatted logs, in Gaggle mode.
 fn test_all_logs_raw_gaggle() {
     run_gaggle_test(TestType::All, "raw");
 }
+
+#[test]
+// Enable pretty-formatted logs.
+fn test_all_logs_pretty() {
+    run_standalone_test(TestType::All, "pretty");
+}
+
+#[test]
+#[serial]
+#[cfg_attr(not(feature = "gaggle"), ignore)]
+// Enable pretty-formatted logs, in Gaggle mode.
+fn test_all_logs_pretty_gaggle() {
+    run_gaggle_test(TestType::All, "pretty");
+}
