@@ -1,4 +1,4 @@
-use httpmock::{Method::GET, MockRef, MockServer};
+use httpmock::{Method::GET, Mock, MockServer};
 use serial_test::serial;
 use tokio::time::{sleep, Duration};
 
@@ -41,9 +41,9 @@ pub async fn one_with_delay(user: &GooseUser) -> GooseTaskResult {
     let _goose = user.get(ONE_PATH).await?;
 
     // "Run out the clock" on the load test when this function runs. Sleep for
-    // the total duration the test is to run plus 1 second to be sure no
+    // the total duration the test is to run plus 2 second to be sure no
     // additional tasks will run after this one.
-    sleep(Duration::from_secs(RUN_TIME as u64 + 1)).await;
+    sleep(Duration::from_secs(RUN_TIME as u64 + 2)).await;
 
     Ok(())
 }
@@ -53,9 +53,9 @@ pub async fn two_with_delay(user: &GooseUser) -> GooseTaskResult {
     let _goose = user.get(TWO_PATH).await?;
 
     // "Run out the clock" on the load test when this function runs. Sleep for
-    // the total duration the test is to run plus 1 second to be sure no
+    // the total duration the test is to run plus 2 second to be sure no
     // additional tasks will run after this one.
-    sleep(Duration::from_secs(RUN_TIME as u64 + 1)).await;
+    sleep(Duration::from_secs(RUN_TIME as u64 + 2)).await;
 
     Ok(())
 }
@@ -82,7 +82,7 @@ pub async fn stop_one(user: &GooseUser) -> GooseTaskResult {
 }
 
 // All tests in this file run against common endpoints.
-fn setup_mock_server_endpoints(server: &MockServer) -> Vec<MockRef> {
+fn setup_mock_server_endpoints(server: &MockServer) -> Vec<Mock> {
     vec![
         // First set up ONE_PATH, store in vector at ONE_KEY.
         server.mock(|when, then| {
@@ -120,7 +120,7 @@ fn common_build_configuration(
 ) -> GooseConfiguration {
     if let Some(expect_workers) = manager {
         common::build_configuration(
-            &server,
+            server,
             vec![
                 "--manager",
                 "--expect-workers",
@@ -135,10 +135,10 @@ fn common_build_configuration(
             ],
         )
     } else if worker.is_some() {
-        common::build_configuration(&server, vec!["--worker"])
+        common::build_configuration(server, vec!["--worker"])
     } else {
         common::build_configuration(
-            &server,
+            server,
             vec![
                 "--users",
                 &USERS.to_string(),
@@ -153,7 +153,7 @@ fn common_build_configuration(
 }
 
 // Helper to confirm all variations generate appropriate results.
-fn validate_test(test_type: &TestType, scheduler: &GooseScheduler, mock_endpoints: &[MockRef]) {
+fn validate_test(test_type: &TestType, scheduler: &GooseScheduler, mock_endpoints: &[Mock]) {
     // START_ONE_PATH is loaded one and only one time on all variations.
     mock_endpoints[START_ONE_KEY].assert_hits(1);
 
@@ -293,7 +293,7 @@ fn run_standalone_test(test_type: &TestType, scheduler: &GooseScheduler) {
     common::run_load_test(goose_attack, None);
 
     // Confirm the load test ran correctly.
-    validate_test(test_type, &scheduler, &mock_endpoints);
+    validate_test(test_type, scheduler, &mock_endpoints);
 }
 
 // Helper to run all gaggle tests.
@@ -373,7 +373,7 @@ fn run_gaggle_test(test_type: &TestType, scheduler: &GooseScheduler) {
     common::run_load_test(manager_goose_attack, Some(worker_handles));
 
     // Confirm the load test ran correctly.
-    validate_test(test_type, &scheduler, &mock_endpoints);
+    validate_test(test_type, scheduler, &mock_endpoints);
 }
 
 #[test]
